@@ -16,6 +16,11 @@ sub backend_block_keywords {
           label   => 'No Gen',
           descr   => 'Skip everything for this backend',
           type    => 'boolean' },
+
+        { keyword => 'template',
+          label   => 'Alternate Template',
+          descr   => 'A custom TT template.',
+          type    => 'text' },
     ];
 }
 
@@ -68,6 +73,15 @@ CREATE [% keyword %] [% name %][% child_output %]
 INSERT INTO [% table %] ( [% columns.join( ', ' ) %] )
     VALUES ( [% values.join( ', ' ) %] );
 [% END %]
+
+[% BLOCK three_way %]
+CREATE TABLE [% table_name %] (
+    id SERIAL PRIMARY KEY,
+[% FOREACH foreign_key IN foreign_keys %]
+    [% foreign_key %] int4[% UNLESS loop.last %],[% END +%]
+[% END %]
+);
+[% END %]
 EO_TT_blocks
 
 sub setup_template {
@@ -87,8 +101,8 @@ sub setup_template {
 }
 
 # sql_block
-package #
-    sql_block;
+package # table_block
+    table_block;
 use strict; use warnings;
 
 sub output_sql {
@@ -97,7 +111,22 @@ sub output_sql {
 
     return if ( $self->_skip_this_block );
 
-    my $child_out_str = join "\n", @{ $child_output };
+    my $child_out_str;
+
+    my %output;
+    foreach my $statement ( @{ $child_output } ) {
+        my ( $type, $output ) = @{ $statement };
+        push @{ $output{ $type } }, $output;
+    }
+
+    $child_out_str = Bigtop::Backend::SQL::Postgres::table_body(
+        { child_output => $output{table_body} }
+    );
+
+    if ( defined $output{insert_statements} ) {
+        $child_out_str .= "\n"
+                       . join "\n", @{ $output{insert_statements} };
+    }
 
     my $output = Bigtop::Backend::SQL::Postgres::sql_block(
         {
@@ -110,45 +139,32 @@ sub output_sql {
     return [ $output ];
 }
 
-# sequence_body
-package #
-    sequence_body;
-use strict; use warnings;
-
-sub output_sql {
-    # XXX for now, just end the line.
-    # Watch this space for something more interesting.
-    return [ ';' ];
-}
-
-# table_body
-package #
-    table_body;
+package # seq_block
+    seq_block;
 use strict; use warnings;
 
 sub output_sql {
     my $self         = shift;
     my $child_output = shift;
 
-    my %output;
-    foreach my $statement ( @{ $child_output } ) {
-        my ( $type, $output ) = @{ $statement };
-        push @{ $output{ $type } }, $output;
-    }
+    return if ( $self->_skip_this_block );
 
-    my $output = Bigtop::Backend::SQL::Postgres::table_body(
-        { child_output => $output{table_body} }
+    my $child_out_str;
+
+    $child_out_str = join( "\n", @{ $child_output }) . ';';
+
+    my $output = Bigtop::Backend::SQL::Postgres::sql_block(
+        {
+            keyword      => $self->get_create_keyword(),
+            child_output => $child_out_str,
+            name         => $self->get_name(),
+        }
     );
 
-    if ( defined $output{insert_statements} ) {
-        $output .= "\n" . join "\n", @{ $output{insert_statements} };
-    }
-
-    return [ $output ]
+    return [ $output ];
 }
 
-# table_element_block
-package #
+package # table_element_block
     table_element_block;
 use strict; use warnings;
 
@@ -171,7 +187,7 @@ sub output_sql {
 
         my @columns;
         my @values;
-        foreach my $insertion ( @{ $self->{__VALUE__} } ) {
+        foreach my $insertion ( @{ $self->{__ARGS__} } ) {
             my ( $column, $value ) = %{ $insertion };
 
             $value = "'$value'" unless $value =~ /^\d+$/;
@@ -191,8 +207,7 @@ sub output_sql {
     }
 }
 
-# field_statement
-package #
+package # field_statement
     field_statement;
 use strict; use warnings;
 
@@ -259,7 +274,7 @@ sub output_sql {
 }
 
 # literal_block
-package #
+package # literal_block
     literal_block;
 use strict; use warnings;
 
@@ -269,6 +284,39 @@ sub output_sql {
     return $self->make_output( 'SQL' );
 }
 
+# join_table
+package # join_table
+    join_table;
+use strict; use warnings;
+
+sub output_sql {
+    my $self         = shift;
+    my $child_output = shift;
+
+    my $three_way    = Bigtop::Backend::SQL::Postgres::three_way(
+        {
+            table_name   => $self->{__NAME__},
+            foreign_keys => $child_output,
+        }
+    );
+
+    return [ $three_way ];
+}
+
+# join_table_statement
+package # join_table_statement
+    join_table_statement;
+use strict; use warnings;
+
+sub output_sql {
+    my $self         = shift;
+    my $child_output = shift;
+
+    my @tables = %{ $self->{__DEF__}->get_first_arg() };
+
+    return \@tables;
+}
+
 1;
 
 __END__
@@ -332,6 +380,34 @@ Note that using 'primary_key' instead of the literal 'PRIMARY KEY' is
 important.  It tells the SQL and the Model back ends that this is the
 primary key.
 
+=head1 METHODS
+
+To keep podcoverage tests happy.
+
+=over 4
+
+=item backend_block_keywords
+
+Tells tentmaker that I understand these config section backend block keywords:
+
+    no_gen
+    template
+
+=item what_do_you_make
+
+Tells tentmaker what this module makes.  Summary: docs/schema.postgres.
+
+=item gen_SQL
+
+Called by Bigtop::Parser to get me to do my thing.
+
+=item setup_template
+
+Called by Bigtop::Parser so the user can substitute an alternate template
+for the hard coded one here.
+
+=back
+
 =head1 AUTHOR
 
 Phil Crow <philcrow2000@yahoo.com>
