@@ -102,7 +102,12 @@ For example, if your app block looks like this:
 
     app MyNS::Apps::Name
 
-the default will be MyNS-Apps-Name under the base_dir.
+the default will be MyNS-Apps-Name under the base_dir.  If you wanted
+extra nesting you could say:
+
+    app_dir `MyNS/Apps/Name`;
+
+then bigtop would make those intervening directories for you.
 
 =back
 
@@ -139,7 +144,7 @@ etc.).  This allows bigtop to call gen_SomeType when the user types:
 =back
 
 The distribution comes with a number of these Bigtop:: backends.
-[ See Bigtop Backends below for a list. ]  If you write a useful one,
+[ See L<Bigtop Backends> below for a list. ]  If you write a useful one,
 please send it in so we can include it in a future release.
 
 As a user, you can mark a file as not to be generated by saying:
@@ -214,9 +219,9 @@ Controller and method blocks are exceptions.  These have a type property
     method name is stub { ... }
 
 The legal values of this property are specified in the
-Bigtop::Backend::Control::
-backend you choose.  See it's docs for a list of the types and what
-they mean, but the trivial type, C<stub>, is always supported.
+Bigtop::Backend::Control:: backend you choose.  See it's docs for a
+list of the types and what they mean, but the trivial type, C<stub>,
+is always supported.
 
 =item Statements
 
@@ -229,13 +234,12 @@ Some examples of statements:
 
 A statement is a legal keyword followed by a value and terminated with a
 semi-colon.  Legal values are numbers, valid Perl idents (including colons),
-anything you enclose in backward quotes (see A Note About Quotes in Strings
+anything you enclose in backward quotes (see 'A Note About Quotes in Strings'
 if you need to embed quotes in strings), and comma separated lists of
 the above.
 
 Note that we sometimes use => instead of comma, they mean substantially
-different things.  Only use => when the backend tells you to.  Always use
-the => when the backend tells you to.
+different things.  Only use => when told to.  Always use the => when told to.
 
 (Footnote on fat commas:  In the grammar, comma is the separator for items
 in a list, while the fat comma (=>) forms a pair which becomes a single
@@ -249,7 +253,7 @@ Which keywords are legal depends on which backends you are using.
 Whether a particular keyword's value will work is up to the backend and to
 whatever program ends up receiving what the backend produced.
 
-=head3 A Note About Quotes in Strings:
+A Note About Quotes in Strings:
 
 You can put whatever you like into backquoted strings (as long as you don't
 like backquotes).  But if you put quotes in such strings, you may need to
@@ -404,8 +408,9 @@ Places Apache directives directly into the root location of the app:
 
 Places perl code immediately under the #!/usr/bin/perl line in either the
 <Perl> block in the generated httpd.conf or in the CGI/FastCGI dispatching
-script.  May be repeated.  Output appears in the same order as the statements
-in the Bigtop file.  Example:
+script (and app.server if you had the CGI backend build one).  May be
+repeated.  Output appears in the same order as the statements in the Bigtop
+file.  Example:
 
     literal PerlTop `    use lib '/home/myuser/perl/lib';`;
 
@@ -453,14 +458,20 @@ they appear in the input.  There is no way to have literal statements
 apply to specific SQL backends.  If you use a literal SQL statement,
 its contents will go into every schema.* file.
 
+=item Conf
+
+(registered by Bigtop::Backend::Conf)
+
+Places config variable/value pairs into the config file at the top level.
+
 =back
 
 There are additional literal statements at other levels.
 
 =back
 
-Currently there are four legal block types at the app level: sequence,
-config, table, and controller.  These are described in detail
+Currently there are five legal block types at the app level: sequence,
+config, table, join_table, and controller.  These are described in detail
 directly below.  
 
 =over 4
@@ -475,7 +486,7 @@ declare the sequence.  Give the sequence a name and a block:
 
     sequence address_seq {}
 
-Currently the block must be empty (but it will eventually allow you to
+Currently the block must be empty (but it might eventually allow you to
 specify things like starting value, increment, etc.).
 
 =item config
@@ -488,9 +499,9 @@ That use is deprecated. ]
 
 This allows you to dump config parameters into your Gantry::Conf instance
 config file, PerlSetVar statements into the root location for your app in
-your httpd.conf, or the equivalent in your cgi dispatching script.  Simply
-list the name of a variable and its value in each statement (remember to
-use backquotes):
+your httpd.conf, or the equivalent in your cgi dispatching script or stand
+alone server.  Simply list the name of a variable and its value in each
+statement (remember to use backquotes):
 
     config {
         dbconn `dbi:Pg:dbname=yourdb` => no_accessor;
@@ -532,8 +543,8 @@ This corresponds directly to an INSERT INTO statement for the given data.
 You may use as many data statements as you like.  Obviously, all fields
 you name must be defined for the table and your values must be of the
 proper SQL type.  Note that it is usually a bad idea to specify a value
-for the primary key, in a data statement, when the table has an sequence
-or other auto-incrementing behavior.
+for the primary key, in a data statement, when the table has
+auto-incrementing behavior.
 
 =item foreign_display `%last_name, %first_name`;
 
@@ -541,7 +552,7 @@ or other auto-incrementing behavior.
 
 This becomes the user's view of rows from this table when other tables point
 to them via a foreign_key.  Always use backquotes.  The formatting is
-simplistic.  Any text, which looks like an ident, abutted against a percent
+simplistic.  Any text, which looks like an ident, abutted after a percent
 must be a field in the table whose value will go in that spot.  Literal
 percents are allowed at the end of the string or with trailing whitespace
 or punctuation (except underscore, '_').  Example:
@@ -557,6 +568,9 @@ that default.
 
     model_base_class Gantry::Utils::AuthCDBI;
 
+To specify the default, use the same statment, but put it in the model's
+backend block in the bigtop config section.
+
 =item not_for
 
 (registered by Bigtop::Backend::Parser, understood by Bigtop::Backend::Model::*
@@ -617,15 +631,9 @@ This column is the primary key.  Multi-column primary keys are not supported.
 (handled by Bigtop::Backend::SQL::* required by Bigtop::Backend::Model::Gantry)
 
 This column's default value will be the next value of the sequence for
-this table, if your database understands sequences.  Otherwise, this will 
-indicate that column should be marked auto-increment, so the database will
-auto-generate a sequence of value for the primary key.
-
-If you use the Postgres model backend (or any future backend for a database
-which supports sequences), it is a fatal error to include auto, unless the
-table has a sequence statement and that sequence is defined by a sequence
-block at the app level.  All this indirection supports multiple tables
-sharing a single sequence.
+this table, if there is one and your database understands sequences.
+Otherwise, this will indicate that column should be marked auto-increment,
+so the database will auto-generate a sequence of value for the primary key.
 
 =back
 
@@ -664,6 +672,8 @@ value the user supplies will have to match this.
 
     html_form_constraint `qr[^\d{5}(-\d{4})?]`;
 
+These are passed to Data::FormValidator, see its docs for full details.
+
 =item html_form_display_size
 
 (registered by Bigtop::Backend::Control::Gantry)
@@ -705,6 +715,10 @@ form's POST processor will see.  Note the careful use of backquotes for
 options with spaces in them.  If your option has any characters that Perl
 wouldn't like in an ident name, use backquotes.
 
+Omit this if your select field is really a foreign key (has a refers_to
+statement).  The user will be allowed to pick from all available rows
+in the foreign key table, seeing each row through its foreign_display.
+
 =item html_form_type
 
 (registered by Bigtop::Backend::Control::Gantry)
@@ -713,7 +727,7 @@ What input type the user will use to enter/edit values of this field.
 
     html_form_type textarea;
 
-Choose from text, textarea, or select.  If you choose select and your
+Choose from text, textarea, or select.  If you choose select, and your
 field does not have a refers_to statement, you need to include the
 html_form_options statement.
 
@@ -750,6 +764,50 @@ belongs_to, has_a, etc.).
 
 =back
 
+=item join_table
+
+=over 4
+
+=item joins (required)
+
+(registered by Bigtop::Backend::SQL and Bigtop::Backend::Model, understood by
+Bigtop::Backend::SQL::SQLite, Bigtop::Backend::SQL::Postgres,
+Bigtop::Backend::SQL::MySQL, and Bigtop::Backend::Model::GantryDBIxClass)
+
+A pair of tables which have a many-to-many relationship.  The order
+of the tables is not important.  Example:
+
+    join_table tshirt_color {
+        joins tshirt => color;
+    }
+
+The name of the join table is arbitrary, but command line tools make it
+by joining the first table's name to the second table's name with an
+underscore.
+
+The has_many relationships will be named for the table, by appending an
+s to the table name.  If that won't work for your table, see the names
+statement directly below.
+
+=item names (optional)
+
+(registered by Bigtop::Backend::SQL and Bigtop::Backend::Model, understood by
+Bigtop::Backend::SQL::SQLite, Bigtop::Backend::SQL::Postgres,
+Bigtop::Backend::SQL::MySQL, and Bigtop::Backend::Model::GantryDBIxClass)
+
+Names default to table names with a trailing s appended so color is called
+colors.  If you want the has_many relationships to have custom names do this:
+
+    join_table fox_sock {
+        joins fox   => sock;
+        names foxes => socks;
+    }
+
+Note that if you are providing one name, you must provide the other one.
+The names should be in the same order as they are in the joins statement.
+
+=back
+
 =item controller
 
     controller Control::Module [ is type ] { ... }
@@ -777,6 +835,13 @@ Puts literal text into the apache location block for this controller.  Example:
 Then, C<require group tech> will appear as the last statement in
 the location block for the controller.
 
+=item literal GantryLocation
+
+(registered by Bigtop::Backend::Conf)
+
+Puts literal variable/value pairs into the Config::General output
+in the GantryLocation for this controller.
+
 =item location
 
 (registered by Bigtop::Backend::HttpdConf, Bigtop::Backend::CGI, and
@@ -815,7 +880,7 @@ added, edited, and deleted by automated CRUD schemes.
 
 Takes a list of modules which will be used at the top of the generated
 module.  Do not include the data model package here, controls_table
-is responsible for using it.  If your controller has a type, you must
+is responsible for using it.  If your controller has a type, you should
 also leave out the module corresponding to that type.  For example,
 if you use the Control Gantry backend and you say
 
@@ -827,7 +892,7 @@ you shouldn't put Gantry::Plugins::CRUD in your uses statement.  Doing
 so will result in duplicate use statements.
 
 By default, modules mentioned in uses statements will appear with import
-lists which explicitly include all items in their @EXPORT.
+lists which explicitly import all items in their @EXPORT.
 But, you may supply the modules to use as a pair, where the key is the name
 of the module and the value is a literal string which becomes the
 import list for the module:
@@ -846,6 +911,10 @@ which will generate:
 
     use Gantry::Utils::AutoCRUD;
 
+To decline imports:
+
+    uses Gantry::Utils::AutoCRUD => `qw()`;
+
 =back
 
 There are three controller types:
@@ -987,7 +1056,7 @@ template processor can find it.
 
 =item row_options
 
-These options are like row options, but they appear at the right side
+These options are like header options, but they appear at the right side
 of each row in the main listing.  Typical example:
 
     row_options Edit, Delete;
@@ -1083,8 +1152,8 @@ details about what the backend makes in this case.
 
 =head1 Bigtop Backends
 
-This section lists the available backends.  Bigtop::Docs::Cookbook
-has the details on what each one makes and where it puts its output.
+This section lists the available backends.  Bigtop::Docs::Cookbook has more
+details on what each one makes and where it puts its output.
 
 =over 4
 
@@ -1135,9 +1204,19 @@ get them.  If you want them in the controller, say this:
 
     Control Gantry { full_use 1; }
 
-In this case, you should probably put a full_use 0; statement somewhere
+In this case, you should probably put a C<full_use 0;> statement somewhere
 else (like in HttpdConf Gantry's block, see below).
 
+Setting full_use to 1 makes it harder to port the app from one engine
+or template engine to another, which is why it isn't the default.
+
+If you use DBIx::Class as your ORM (which we recommend), make sure
+to include C<dbix 1;>.  In normal use, DBIx::Class performs queries
+via a call to resultset on the schema for your whole database.  That
+requires slightly different coding than directly querying the models.
+Hence this flag.  It defaults to false, but that is subject change
+since dbic is now our preferred ORM.
+
 =item HttpdConf Gantry
 
 You may turn off PerlSetVar generation for app and controller level config
@@ -1174,10 +1253,15 @@ Allows you to include a gantry_wrapper statement in its config block:
 
 The path needs to point to a wrapper with the structure of the
 sample_wrapper.tt that ships with Gantry.  By default, the backend
-just uses the one that came with Gantry.
+just uses the one that came with Gantry.  So, you don't usually need
+this statement.
+
+=item SQL SQLite
 
 =item SQL Postgres
 
+=item SQL MySQL
+
 =back
 
 =head1 AUTHOR
